<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Register Theme Scripts
 * https://developer.wordpress.org/reference/hooks/wp_enqueue_scripts/
 */
function ditto_scripts() {
  wp_enqueue_style( 'core', get_template_directory_uri() . '/style.css' );
  wp_enqueue_style( 'main-styles', get_template_directory_uri() . '/css/main.bundle.css' );
  wp_enqueue_style('bootstrap.css', get_template_directory_uri() . '/css/bootstrap.min.css');
  wp_enqueue_style('owl-carousel.css', get_template_directory_uri() . '/css/owl.carousel.min.css');

  wp_enqueue_script( 'main-scripts', get_template_directory_uri() . '/js/main.bundle.js', array( 'jquery' ), '', true );
  wp_enqueue_script('jquery.js', get_template_directory_uri() . '/js/jquery-3.5.1.min.js', true);
  wp_enqueue_script('bootstrap.js',  get_template_directory_uri() . '/js/bootstrap.min.js');
  wp_enqueue_script('owl-carousel.js', get_template_directory_uri() . '/js/owl.carousel.min.js');
  wp_enqueue_script('font-awesome.js', get_template_directory_uri() . '/js/font-awesome.js');
  wp_enqueue_script('gsap.js', get_template_directory_uri() . '/js/gsap.js');
  wp_enqueue_script('scrollTrigger.js', get_template_directory_uri() . '/js/scrollTrigger.js');
  wp_register_script('custom.js', get_template_directory_uri() . '/js/custom.js', array('jquery'), '1', true);
  wp_enqueue_script('custom.js');
  wp_register_script('animations.js', get_template_directory_uri() . '/js/animations.js', array('jquery'), '1', true);
  wp_enqueue_script('animations.js');
}
add_action( 'wp_enqueue_scripts', 'ditto_scripts');

/**
 * Register Navigation Menus
 * https://developer.wordpress.org/reference/functions/register_nav_menus/
 */
function ditto_navigation_menus() {
  $locations = array(
    'main_menu' => __( 'Main Menu', 'text_domain' )
  );
  register_nav_menus( $locations );
}
add_action( 'init', 'ditto_navigation_menus' );

/**
 * Theme support
 * https://developer.wordpress.org/reference/functions/add_theme_support/
 */
add_theme_support( 'custom-logo' );

/**
 * Login Styles
 */
function ditto_login_styles() { ?>
  <style type="text/css">
    body {
      background-color: #222 !important;
    }
    #login h1 a, .login h1 a {
      display: none;
    }
    #login h1 img {
      width: 100%;
      max-width: 240px;
      max-height: 180px;
    }
  </style>
  <script type="text/javascript">
    document.addEventListener("DOMContentLoaded", function(event) { 
      let loginImg = document.createElement("img");
        loginImg.src = "<?= get_template_directory_uri() ?>/images/pipe-code-logo.svg";
        loginImg.alt = "WordPress login image";
        document.querySelector('#login h1').appendChild(loginImg);
    });
  </script>
<?php }
add_action( 'login_enqueue_scripts', 'ditto_login_styles' );

/**
 * Install latest jQuery version 3.5.1
 */
if (!is_admin()) {
	wp_deregister_script('jquery');
	wp_register_script('jquery', ("https://ajax.googleapis.com/ajax/libs/jquery/3.5.1/jquery.min.js"), false);
	wp_enqueue_script('jquery');
}

/**
 * Disable Gutenberg
 */
add_filter('use_block_editor_for_post', '__return_false', 10);
add_filter('use_block_editor_for_post_type', '__return_false', 10);
/*
*  Options
*/
if (function_exists('acf_add_options_page')) {
  acf_add_options_page(array(
    'page_title'    => 'Theme Settings',
    'menu_title'    => 'Theme Settings',
    'menu_slug'     => 'theme-settings',
    'capability'    => 'edit_posts',
    'redirect'      =>  true
  ));
  acf_add_options_sub_page(array(
    'page_title'     => 'Header',
    'menu_title'     => 'Header',
    'parent_slug'   => 'theme-settings',
  ));
  acf_add_options_sub_page(array(
    'page_title'     => 'Footer',
    'menu_title'     => 'Footer',
    'parent_slug'   => 'theme-settings',
  ));
  acf_add_options_sub_page(array(
    'page_title'     => 'Colors globals',
    'menu_title'     => 'Colors globals',
    'parent_slug'   => 'theme-settings',
  ));
  acf_add_options_sub_page(array(
    'page_title'     => '404',
    'menu_title'     => '404',
    'parent_slug'   => 'theme-settings',
  ));
}
/*================ Sustainability custom post type =================*/
add_theme_support('post-thumbnails');
add_post_type_support( 'sustainability', 'thumbnail' );
function sustainability_post()
{
  /*====== Argument post type =====*/
  $arg = array(
    'public' => true,
    'has_archive' => true,
    'label'  => 'Sustainability',
    'menu_icon' => 'dashicons-chart-area',
    'supports' => ['title', 'editor', 'thumbnail'],
    'taxonomies' => array('sustainabiliti_cat')
  );
  /*============ Register post type ============*/
  register_post_type('sustainability', $arg);
  /*============ Register taxonomy of fqas ============*/
   /*============ Argument taxonimy ============*/
   $labels = array(
    'name' => _x('Category', 'taxonomy general name'),
    'singular_name' => _x('Category', 'taxonomy singular name'),
    'search_items' =>  __('Search Category'),
    'all_items' => __('All Category'),
    'parent_item' => __('Parent Category'),
    'parent_item_colon' => __('Parent Category:'),
    'edit_item' => __('Edit Category'),
    'update_item' => __('Update Category'),
    'add_new_item' => __('Add New Category'),
    'new_item_name' => __('New Category Name'),
    'menu_name' => __('Category'),
  );
  /*========== Register taxonomi ==========*/
  register_taxonomy('sustainabiliti_cat', array('sustainability'), array(
    'hierarchical' => true,
    'labels' => $labels,
    'show_ui' => true,
    'show_in_rest' => true,
    'show_admin_column' => true,
    'query_var' => true,
    'rewrite' => array('slug' => 'sustainabiliti_cat'),
  ));
};
add_action('init', 'sustainability_post');
/*================ Events ===============*/
add_theme_support('post-thumbnails');
add_post_type_support( 'events', 'thumbnail' );
function events_post()
{
  /*====== Argument post type =====*/
  $event = array(
    'public' => true,
    'has_archive' => true,
    'label'  => 'Events',
    'menu_icon' => 'dashicons-media-interactive',
    'supports' => ['title', 'editor', 'thumbnail'],
  );
  /*============ Register post type ============*/
  register_post_type('events', $event);
 
};
add_action('init', 'events_post');
/*============ api for filter to sustainabilities posts ============*/
add_action('rest_api_init', function(){
  register_rest_route( 'sustainability', '/list', array(
    array(
        'methods'               => WP_REST_Server::READABLE,
        'callback'              => 'post_list_handler',
        'permission_callback'   => '__return_true',          
    )
  ));
});
function post_list_handler($request){
  $sustainabilities = [
    'post_type' => 'sustainability',
    'post_status' => 'publish',
    'sustainabiliti_cat' => $request['cat'],
    'posts_per_page'    => $request['items'],
    'orderby'         => 'DESC'
  ];
  $news = new WP_Query($sustainabilities);
  $sustainability = array();
  while ($news->have_posts()) {
    $news->the_post();
    array_push($sustainability, array(
      'title' => get_the_title($news->ID),
      'thumbnail'     => get_the_post_thumbnail_url($news->ID),
      'short_description' => get_field('short_description', $news->ID),
      'permalink' => get_the_permalink($news->ID)
    ));
    wp_reset_postdata();
  }
  return $sustainability;
}